@@ -43,7 +43,7 @@ distribution.
 #include <assert.h>
 
 // Help out windows:
-#if defined( __APPLE__ ) && defined( _DEBUG ) && !defined( DEBUG )
+#if !defined( __APPLE__ ) && defined( _DEBUG ) && !defined( DEBUG )
 #define DEBUG
 #endif
 
